# Insert your code here. 

import os 

os.system('echo kontogu core been import ...')

#os.system('curl cip.cc')

def startup(id=450, platform='replit', tags=''):

    #cmd = 'curl -L -O https://fhost.devxops.eu.org/devops/cicd/startups/{}-startup.sh; bash {}-startup.sh {} {} {};'.format(platform, platform, id, platform, tags)
    cmd = 'echo hare is startup for test .... '
    
    os.system(cmd)
    print('ok , finish')
    #os.system('sleep 24h')
